#
# spec file for package python-autopage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-autopage
Version:        0.5.2
Release:        2.2
Summary:        A library to provide automatic paging for console output
License:        Apache-2.0
URL:            https://github.com/zaneb/autopage
Source:         https://files.pythonhosted.org/packages/source/a/autopage/autopage-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Autopage is a Python library to
automatically display terminal output from a program
in a pager (like `less`)

%prep
%autosetup -p1 -n autopage-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# Do not distribute tests with the package
%python_expand rm -rf %{buildroot}%{$python_sitelib}/autopage/tests

%check
unset LESS
rm -v autopage/tests/test_end_to_end.py
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/autopage
%{python_sitelib}/autopage-%{version}.dist-info

%changelog
* Mon Feb  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch support-python-311.patch, no longer required.
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.2:
  * Always return an integer error code from exit_code()
  * Fix line buffering detection for TTYs on Illumos/Solaris
  * Numerous improvements to the integration tests:
  - Work correctly with less v633
  - Fix flaky tests
  - Improve behaviour and debugging when tests fail
  - Allow test runners to capture stdout of all child processes
  * Update test dependencies to account for recent releases of
    fixtures
  * Test using a more recent version of mypy
  * Run tests on Python 3.11 and 3.12
  main
* Wed Jan 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python-311.patch:
  * Support Python 3.11 changes.
* Mon Nov 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Do not distribute tests with the package
- Build using %%pyproject macros
- Remove python_module macro definition
- More specific python_sitelib in %%files
- Remove duplicate files with %%fdupes
* Thu Aug  4 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 0.5.1:
  * integration tests: Increase timeout for subprocess to exit
* Wed Feb 23 2022 Dirk Müller <dmueller@suse.com>
- skip end-to-end test, they hang in OBS
* Tue Feb 22 2022 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Testing on Python 3.10.
  * More (optional) strategies for selecting the pager command to use.
  * Fully-automated integration testing.
  * Support for type checking by consumers using PEP561.
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- skip python2 build, it doesn't work anymore
* Tue Oct 26 2021 Dirk Müller <dmueller@suse.com>
- Initial package (0.4.0)
